MessageBodyModel class

Umeng Push Message Body Content

Constructors

MessageBodyModel.fromJson(Map<String, dynamic> json)

Properties

activity ↔ String
getter/setter pair
afterOpen ↔ String
getter/setter pair
custom ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
playLights ↔ String
getter/setter pair
playSound ↔ String
getter/setter pair
playVibrate ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
ticker ↔ String
getter/setter pair
title ↔ String
getter/setter pair
url ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited